generate2dkmesh — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# generate2dkmesh

pyprocar.scripts.generate2dkmesh(x1: float, y1: float, x2: float, y2: float, z: float, nkx: int, nky: int)

  _summary_

  Parameters:

    - x1 (float) – The beginning value to generate x coords

    - y1 (float) – The beginning value to generate y coords

    - x2 (float) – The end value to generate x coords

    - y2 (float) – The end value to generate y coords

    - z (float) – The z coordinate

    - nkx (int) – The number of points to generate in the x direction

    - nky (int) – The number of points to generate in the y direction

  Returns:

    _type_ – _description_